.. _spkg_uri_template:

uri_template: RFC 6570 URI Template Processor
=============================================

Description
-----------

RFC 6570 URI Template Processor

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/uri-template/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.3.0

version_requirements.txt::

    uri-template

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install uri-template

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i uri_template


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
